"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.startDevServer = void 0;
const colors_1 = __importDefault(require("colors"));
const configureWebPack_1 = require("./configureWebPack");
const webpack_1 = __importDefault(require("webpack"));
const webpack_dev_server_1 = __importDefault(require("webpack-dev-server"));
const logger_1 = require("../common/logger");
const commander_1 = require("commander");
const settingsManager_1 = require("../common/settingsManager");
commander_1.program.option('--config <config>').parse();
const settings = JSON.parse(commander_1.program.opts().config);
(0, settingsManager_1.applySettings)(settings);
function startDevServer() {
    return __awaiter(this, void 0, void 0, function* () {
        try {
            const config = yield (0, configureWebPack_1.resultConfig)();
            const compiler = (0, webpack_1.default)(config);
            const server = new webpack_dev_server_1.default(compiler, config.devServer);
            logger_1.Logger.log(`To load your scripts, use this query string: ${colors_1.default.yellow(`?debug=true&noredir=true&debugManifestsFile=https://${config.devServer.host}:${config.devServer.port}/temp/manifests.js`)}`);
            server.listen(config.devServer.port, config.devServer.host, (err) => {
                if (err) {
                    console.log('An error occured while running web pack dev server. Details:');
                    console.log(err);
                }
            });
        }
        catch (error) {
            if (error) {
                logger_1.Logger.error((error === null || error === void 0 ? void 0 : error.message) || error.toString());
                throw error;
            }
            else {
                logger_1.Logger.error('The process exited with an error');
                process.exit(1);
            }
        }
    });
}
exports.startDevServer = startDevServer;
startDevServer();
//# sourceMappingURL=devServer.js.map